==> nextcloud-app-mail-0.21.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/ca.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Correu electrònic",
    "Auto detect failed. Please use manual mode." : "La detecció automàtica ha fallat. Si us plau, feu servir el mode manual.",
    "Updating account failed: " : "Ha fallat l’actualització del compte:",
    "Creating account failed: " : "Ha fallat la creació del compte:",
    "💌 A mail app for Nextcloud" : "💌 Una aplicació de correu per a Nextcloud",
    "Auto" : "Auto",
    "Name" : "Nom",
    "Mail Address" : "Adreça de correu",
    "Password" : "Contrasenya",
    "Manual" : "Manual",
    "IMAP Settings" : "Paràmetres IMAP",
    "IMAP Host" : "Servidor IMAP",
    "IMAP Security" : "Seguretat IMAP",
    "None" : "Cap",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Port IMAP",
    "IMAP User" : "Usuari IMAP",
    "IMAP Password" : "Contrasenya IMAP",
    "SMTP Settings" : "Paràmetres SMTP",
    "SMTP Host" : "Servidor SMTP",
    "SMTP Security" : "Seguretat SMTP",
    "SMTP Port" : "Port SMTP",
    "SMTP User" : "Usuari SMTP",
    "SMTP Password" : "Contrasenya SMTP",
    "Save" : "Desa",
    "Connect" : "Connecta",
    "Add mail account" : "Afegeix compte de correu",
    "Use Gravatar and favicon avatars" : "Fes servir avatars de Gravatar i favicon",
    "Keyboard shortcuts" : "Dreceres de teclat",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Esteu cercant una manera de xifrar els vostres correus electrònics? Instal·leu l’extensió del navegador Mailvelope.",
    "From" : "De",
    "Select account" : "Selecciona un compte",
    "To" : "A",
    "+ Copy" : "+ Copia",
    "Copy" : "Copia",
    "No contacts found." : "No s'han trobat contactes.",
    "Subject" : "Assumpte",
    "Subject …" : "Assumpte …",
    "Write message …" : "Escriu missatge …",
    "Saving draft …" : "S'està desant l'esborrany ...",
    "Draft saved" : "S'ha desat l'esborrany",
    "Upload attachment" : "Carrega l'adjunt",
    "Add attachment from Files" : "Afegeix adjunts des dels fitxers",
    "Uploading attachments …" : "S'estan carregant els adjunts ...",
    "Sending …" : "S'està enviant ...",
    "Error sending your message" : "S'ha produït un error mentre s'enviava el vostre missatge",
    "Go back" : "Torna enrere",
    "Retry" : "Reintenta",
    "Message sent!" : "Missatge enviat!",
    "Reply sent!" : "Resposta enviada!",
    "Write another message" : "Escriu un altre missatge",
    "Send" : "Envia",
    "Uploading {percent}% …" : "S'està carregant {percent}% ...",
    "Choose a file to add as attachment" : "Trieu un fitxer per afegir als adjunts",
    "Writing mode" : "Mode d'escriptura",
    "Plain text" : "Text net",
    "Rich text" : "Text enriquit",
    "No messages in this folder" : "No hi ha missatges en aquesta carpeta",
    "Draft: " : "Esborrany:",
    "Mark read" : "Marca com a llegit",
    "Mark unread" : "Marca com a no llegit",
    "Delete" : "Suprimeix",
    "Report this bug" : "Informa d'aquest error",
    "Loading messages" : "S'estan carregant missatges",
    "Not found" : "No s'ha trobat",
    "Reply" : "Respon",
    "Reply to sender only" : "Respon només al remitent",
    "Forward" : "Endavant",
    "Could not load your message" : "No s’ha pogut carregar el vostre missatge",
    "Import into calendar" : "Importa al calendari",
    "Download attachment" : "Descarrega l'adjunt",
    "Save to Files" : "Desa els fitxers",
    "Choose a folder to store the attachment in" : "Trieu una carpeta per emmagatzemar-hi el fitxer adjunt",
    "Save all to Files" : "Desa tots els fitxers",
    "Choose a folder to store the attachments in" : "Trieu una carpeta per emmagatzemar-hi els fitxers adjunts",
    "The images have been blocked to protect your privacy." : "S'han blocat les imatges per protegir la vostra privadesa.",
    "Show images from this\tsender" : "Mostra les imatges d'aquest\tremitent",
    "New message" : "Nou missatge",
    "Settings" : "Paràmetres",
    "Edit account" : "Edita el compte",
    "Add folder" : "Afegeix una carpeta",
    "Delete account" : "Suprimeix el compte",
    "Show all folders" : "Mostra totes les carpetes",
    "Collapse folders" : "Replega les carpetes",
    "Mark all as read" : "Marca-ho tot com a llegit",
    "Mark all messages of this folder as read" : "Marca tots els missatges d'aquesta carpeta com a llegits",
    "Add subfolder" : "Afegeix una subcarpeta",
    "{total} messages" : "{total} missatges",
    "{unread} unread of {total}" : "{unread} no llegits de {total}",
    "Loading …" : "Carregant …",
    "Could not load your draft" : "No s’ha pogut carregar el vostre esborrany",
    "Could not load original message" : "No s'ha pogut carregar el missatge original",
    "No message selected" : "No s'ha seleccionat cap missatge",
    "Signature" : "Signatura",
    "General" : "General",
    "Email address" : "Adreça de correu electrònic",
    "User" : "Usuari",
    "Host" : "Servidor",
    "Port" : "Port",
    "Account settings" : "Paràmetres del compte",
    "Change name" : "Canvia el nom",
    "Mail server" : "Servidor de correu electrònic",
    "Speed up your Mail experience with these quick shortcuts." : "Accelereu l’experiència del correu electrònic amb aquestes dreceres ràpides.",
    "Compose new message" : "Crea un missatge nou",
    "Newer message" : "Missatges més nous",
    "Older message" : "Missatges més vells",
    "Toggle star" : "Commuta l'estrella",
    "Toggle unread" : "Commuta la lectura",
    "Search" : "Cerca",
    "Refresh" : "Refresca",
    "Connect your mail account" : "Connecteu el vostre compte de correu electrònic",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nou missatge\nde {from}","%n nous missatges\nde {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Could not load {tag}{name}{endtag}" : "No s'ha pogut carregar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "S'ha produït un problema mentre es carregava {tag}{name}{endtag}",
    "Could not load the desired message" : "No s’ha pogut carregar el missatge desitjat",
    "Could not load the message" : "No s’ha pogut carregar el missatge",
    "Error loading message" : "S'ha produït un error mentre es carregava el missatge",
    "Forwarding to %s" : "S'està reenviant a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Premeu aquí si no se us redirigeix automàticament d'aquí pocs segons.",
    "Redirect" : "Redirigeix",
    "The link leads to %s" : "L'enllaç porta a %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no voleu visitar aquesta pàgina, podeu tornar a <a href=\"%s\">Mail</a>.",
    "Continue to %s" : "Continua a %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-1.3.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/ca.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Correu",
    "Auto detect failed. Please use manual mode." : "La detecció automàtica ha fallat. Si us plau, feu servir el mode manual.",
    "Updating account failed: " : "Ha fallat l’actualització del compte:",
    "Creating account failed: " : "Ha fallat la creació del compte:",
    "💌 A mail app for Nextcloud" : "💌 Una aplicació de correu per a Nextcloud",
    "Auto" : "Automàtic",
    "Name" : "Nom",
    "Mail Address" : "Adreça de correu",
    "Password" : "Contrasenya",
    "Manual" : "Manual",
    "IMAP Settings" : "Paràmetres IMAP",
    "IMAP Host" : "Servidor IMAP",
    "IMAP Security" : "Seguretat IMAP",
    "None" : "Cap",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Port IMAP",
    "IMAP User" : "Usuari IMAP",
    "IMAP Password" : "Contrasenya IMAP",
    "SMTP Settings" : "Paràmetres SMTP",
    "SMTP Host" : "Servidor SMTP",
    "SMTP Security" : "Seguretat SMTP",
    "SMTP Port" : "Port SMTP",
    "SMTP User" : "Usuari SMTP",
    "SMTP Password" : "Contrasenya SMTP",
    "Save" : "Desa",
    "Connect" : "Connecta",
    "Add mail account" : "Afegeix compte de correu",
    "Use Gravatar and favicon avatars" : "Fes servir avatars de Gravatar i favicon",
    "Keyboard shortcuts" : "Dreceres de teclat",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Esteu cercant una manera de xifrar els vostres correus electrònics? Instal·leu l’extensió del navegador Mailvelope.",
    "From" : "De",
    "Select account" : "Selecciona un compte",
    "To" : "A",
    "No contacts found." : "No s'han trobat contactes.",
    "Subject" : "Assumpte",
    "Subject …" : "Assumpte …",
    "Write message …" : "Escriu missatge …",
    "Saving draft …" : "S'està desant l'esborrany ...",
    "Draft saved" : "S'ha desat l'esborrany",
    "Upload attachment" : "Carrega l'adjunt",
    "Add attachment from Files" : "Afegeix adjunts des dels fitxers",
    "Uploading attachments …" : "S'estan carregant els adjunts ...",
    "Sending …" : "S'està enviant ...",
    "Error sending your message" : "S'ha produït un error mentre s'enviava el vostre missatge",
    "Go back" : "Torna enrere",
    "Retry" : "Reintenta",
    "Message sent!" : "Missatge enviat!",
    "Write another message" : "Escriu un altre missatge",
    "Send" : "Envia",
    "Uploading {percent}% …" : "S'està carregant {percent}% ...",
    "Choose a file to add as attachment" : "Trieu un fitxer per afegir als adjunts",
    "Writing mode" : "Mode d'escriptura",
    "Plain text" : "Text net",
    "Rich text" : "Text enriquit",
    "No messages in this folder" : "No hi ha missatges en aquesta carpeta",
    "Draft: " : "Esborrany:",
    "Unfavorite" : "Treu de favorits",
    "Favorite" : "Preferit",
    "Mark read" : "Marca com a llegit",
    "Mark unread" : "Marca com a no llegit",
    "Delete" : "Suprimeix",
    "Report this bug" : "Informa d'aquest error",
    "Loading messages" : "S'estan carregant missatges",
    "Not found" : "No s'ha trobat",
    "to" : "a",
    "cc" : "cc",
    "Reply" : "Respon",
    "Reply to sender only" : "Respon només al remitent",
    "Forward" : "Reenvia",
    "Could not load your message" : "No s’ha pogut carregar el vostre missatge",
    "Import into calendar" : "Importa al calendari",
    "Download attachment" : "Descarrega l'adjunt",
    "Save to Files" : "Desa els fitxers",
    "Unnamed" : "Sense nom",
    "Choose a folder to store the attachment in" : "Trieu una carpeta per emmagatzemar-hi el fitxer adjunt",
    "Save all to Files" : "Desa tots els fitxers",
    "Choose a folder to store the attachments in" : "Trieu una carpeta per emmagatzemar-hi els fitxers adjunts",
    "The images have been blocked to protect your privacy." : "S'han blocat les imatges per protegir la vostra privadesa.",
    "Show images from this\tsender" : "Mostra les imatges d'aquest\tremitent",
    "New message" : "Escriu un missatge",
    "Settings" : "Paràmetres",
    "Edit account" : "Edita el compte",
    "Add folder" : "Afegeix una carpeta",
    "Delete account" : "Suprimeix el compte",
    "Show all folders" : "Mostra totes les carpetes",
    "Collapse folders" : "Replega les carpetes",
    "Mark all as read" : "Marca-ho tot com a llegit",
    "Mark all messages of this folder as read" : "Marca tots els missatges d'aquesta carpeta com a llegits",
    "Add subfolder" : "Afegeix una subcarpeta",
    "Loading …" : "Carregant …",
    "Could not load your draft" : "No s’ha pogut carregar el vostre esborrany",
    "Could not load original message" : "No s'ha pogut carregar el missatge original",
    "No message selected" : "No s'ha seleccionat cap missatge",
    "Signature" : "Signatura",
    "General" : "General",
    "Email address" : "Adreça de correu electrònic",
    "User" : "Usuari",
    "Host" : "Servidor",
    "Port" : "Port",
    "Account settings" : "Paràmetres del compte",
    "Change name" : "Canvia el nom",
    "Mail server" : "Servidor de correu electrònic",
    "Speed up your Mail experience with these quick shortcuts." : "Accelereu l’experiència del correu electrònic amb aquestes dreceres ràpides.",
    "Compose new message" : "Crea un missatge nou",
    "Newer message" : "Missatges més nous",
    "Older message" : "Missatges més vells",
    "Toggle star" : "Commuta l'estrella",
    "Toggle unread" : "Commuta la lectura",
    "Search" : "Cerca",
    "Refresh" : "Refresca",
    "Connect your mail account" : "Connecteu el vostre compte de correu electrònic",
    "All" : "Totes",
    "Archive" : "Arxiu",
    "Drafts" : "Esborranys",
    "Favorites" : "Favorits",
    "All inboxes" : "Totes les safates d'entrada",
    "Inbox" : "Safata d'entrada",
    "Junk" : "Brossa",
    "Sent" : "Enviats",
    "Trash" : "Paperera",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nou missatge\nde {from}","%n nous missatges\nde {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Could not load {tag}{name}{endtag}" : "No s'ha pogut carregar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "S'ha produït un problema mentre es carregava {tag}{name}{endtag}",
    "Could not load the desired message" : "No s’ha pogut carregar el missatge desitjat",
    "Could not load the message" : "No s’ha pogut carregar el missatge",
    "Error loading message" : "S'ha produït un error mentre es carregava el missatge",
    "Forwarding to %s" : "S'està reenviant a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Premeu aquí si no se us redirigeix automàticament d'aquí pocs segons.",
    "Redirect" : "Redirigeix",
    "The link leads to %s" : "L'enllaç porta a %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no voleu visitar aquesta pàgina, podeu tornar a <a href=\"%s\">Mail</a>.",
    "Continue to %s" : "Continua a %s"
},
"nplurals=2; plural=(n != 1);");
